@@ -13,8 +13,9 @@ def init():
 
 @click.command(help="Store file in IPFS")
 @click.argument('filename')
-def store_file(filename: str):
-    uri = kc.store_file(filename, label=os.path.basename(filename))
+@click.option('--cache-locally', is_flag=True)
+def store_file(filename: str, cache_locally: bool):
+    uri = kc.store_file(filename, label=os.path.basename(filename), cache_locally=cache_locally)
     print(uri)
 
 @click.command(help="Load file from IPFS")
@@ -30,8 +31,9 @@ def cat_file(uri: str):
 
 @click.command(help="Store file in the local cache")
 @click.argument('filename')
-def store_file_local(filename: str):
-    uri = kc.store_file_local(filename, label=os.path.basename(filename))
+@click.option('--reference', is_flag=True)
+def store_file_local(filename: str, reference: bool):
+    uri = kc.store_file_local(filename, label=os.path.basename(filename), reference=reference)
     print(uri)
 
 cli.add_command(init)
