@@ -1,4 +1,6 @@
 from typing import Union
+
+from .get_project_id import get_project_id
 from ._kacherycloud_request import _kacherycloud_request
 
 
@@ -12,6 +14,8 @@ def set_mutable(key: str, value: str, *, project_id: Union[str, None]=None):
     }
     if project_id is not None:
         payload['projectId'] = project_id
+    else:
+        payload['projectId'] = get_project_id()
     response = _kacherycloud_request(payload)
 
 def get_mutable(key: str, *, project_id: Union[str, None]=None):
@@ -21,6 +25,8 @@ def get_mutable(key: str, *, project_id: Union[str, None]=None):
     }
     if project_id is not None:
         payload['projectId'] = project_id
+    else:
+        payload['projectId'] = get_project_id()
     response = _kacherycloud_request(payload)
     if not response['found']:
         return None
